pub struct AddPeerRequestMessage {
pub address: String,
pub is_permanent: bool,
}Expand description
AddPeerRequestMessage adds a peer to kaspad’s outgoing connection list. This will, in most cases, result in kaspad connecting to said peer.
Fields
address: Stringis_permanent: boolWhether to keep attempting to connect to this peer after disconnection