GetBlockCountRequestMessage

Struct GetBlockCountRequestMessage 

pub struct GetBlockCountRequestMessage {}
GetBlockCountRequestMessage requests the current number of blocks in this kaspad. Note that this number may decrease as pruning occurs.