pub struct GetBlockCountResponseMessage {
pub block_count: u64,
pub header_count: u64,
pub error: Option<RpcError>,
}Fields
block_count: u64header_count: u64error: Option<RpcError>Trait Implementations
Sourceimpl Clone for GetBlockCountResponseMessage
impl Clone for GetBlockCountResponseMessage
Sourcefn clone(&self) -> GetBlockCountResponseMessage
fn clone(&self) -> GetBlockCountResponseMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetBlockCountResponseMessage
impl Debug for GetBlockCountResponseMessage
Sourceimpl From<GetBlockCountResponseMessage> for KaspadResponse
impl From<GetBlockCountResponseMessage> for KaspadResponse
Sourcefn from(item: GetBlockCountResponseMessage) -> Self
fn from(item: GetBlockCountResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<GetBlockCountResponseMessage> for Payload
impl From<GetBlockCountResponseMessage> for Payload
Sourcefn from(item: GetBlockCountResponseMessage) -> Self
fn from(item: GetBlockCountResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<&BlockCount, RpcError>> for GetBlockCountResponseMessage
impl From<Result<&BlockCount, RpcError>> for GetBlockCountResponseMessage
Sourcefn from(item: RpcResult<&GetBlockCountResponse>) -> Self
fn from(item: RpcResult<&GetBlockCountResponse>) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<BlockCount, RpcError>> for GetBlockCountResponseMessage
impl From<Result<BlockCount, RpcError>> for GetBlockCountResponseMessage
Sourcefn from(item: RpcResult<GetBlockCountResponse>) -> Self
fn from(item: RpcResult<GetBlockCountResponse>) -> Self
Converts to this type from the input type.
Sourceimpl From<RpcError> for GetBlockCountResponseMessage
impl From<RpcError> for GetBlockCountResponseMessage
Sourceimpl Message for GetBlockCountResponseMessage
impl Message for GetBlockCountResponseMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for GetBlockCountResponseMessage