pub struct GetVirtualChainFromBlockRequestMessage {
pub start_hash: String,
pub include_accepted_transaction_ids: bool,
}Expand description
/ GetVirtualChainFromBlockRequestMessage requests the virtual selected
/ parent chain from some startHash to this kaspad’s current virtual
/ Note:
/ this call batches the response to:
/ a. the network’s mergeset size limit * 10 amount of added chain blocks, if includeAcceptedTransactionIds = false
/ b. or mergeset size limit * 10 amount of merged blocks, if includeAcceptedTransactionIds = true
/ c. it does not batch the removed chain blocks, only the added ones.
Fields
start_hash: Stringinclude_accepted_transaction_ids: boolTrait Implementations
Sourceimpl Clone for GetVirtualChainFromBlockRequestMessage
impl Clone for GetVirtualChainFromBlockRequestMessage
Sourcefn clone(&self) -> GetVirtualChainFromBlockRequestMessage
fn clone(&self) -> GetVirtualChainFromBlockRequestMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<&GetVirtualChainFromBlockRequest> for GetVirtualChainFromBlockRequestMessage
impl From<&GetVirtualChainFromBlockRequest> for GetVirtualChainFromBlockRequestMessage
Sourcefn from(item: &GetVirtualChainFromBlockRequest) -> Self
fn from(item: &GetVirtualChainFromBlockRequest) -> Self
Converts to this type from the input type.
Sourceimpl From<GetVirtualChainFromBlockRequestMessage> for KaspadRequest
impl From<GetVirtualChainFromBlockRequestMessage> for KaspadRequest
Sourcefn from(item: GetVirtualChainFromBlockRequestMessage) -> Self
fn from(item: GetVirtualChainFromBlockRequestMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<GetVirtualChainFromBlockRequestMessage> for Payload
impl From<GetVirtualChainFromBlockRequestMessage> for Payload
Sourcefn from(item: GetVirtualChainFromBlockRequestMessage) -> Self
fn from(item: GetVirtualChainFromBlockRequestMessage) -> Self
Converts to this type from the input type.
Sourceimpl Message for GetVirtualChainFromBlockRequestMessage
impl Message for GetVirtualChainFromBlockRequestMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetVirtualChainFromBlockRequestMessage
impl PartialEq for GetVirtualChainFromBlockRequestMessage
Sourcefn eq(&self, other: &GetVirtualChainFromBlockRequestMessage) -> bool
fn eq(&self, other: &GetVirtualChainFromBlockRequestMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetVirtualChainFromBlockRequestMessage