pub struct GetVirtualChainFromBlockResponseMessage {
pub removed_chain_block_hashes: Vec<String>,
pub added_chain_block_hashes: Vec<String>,
pub accepted_transaction_ids: Vec<RpcAcceptedTransactionIds>,
pub error: Option<RpcError>,
}Fields
removed_chain_block_hashes: Vec<String>The chain blocks that were removed, in high-to-low order
added_chain_block_hashes: Vec<String>The chain blocks that were added, in low-to-high order
accepted_transaction_ids: Vec<RpcAcceptedTransactionIds>The transactions accepted by each block in addedChainBlockHashes.
Will be filled only if includeAcceptedTransactionIds = true in the request.
error: Option<RpcError>Trait Implementations
Sourceimpl Clone for GetVirtualChainFromBlockResponseMessage
impl Clone for GetVirtualChainFromBlockResponseMessage
Sourcefn clone(&self) -> GetVirtualChainFromBlockResponseMessage
fn clone(&self) -> GetVirtualChainFromBlockResponseMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<GetVirtualChainFromBlockResponseMessage> for KaspadResponse
impl From<GetVirtualChainFromBlockResponseMessage> for KaspadResponse
Sourcefn from(item: GetVirtualChainFromBlockResponseMessage) -> Self
fn from(item: GetVirtualChainFromBlockResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<GetVirtualChainFromBlockResponseMessage> for Payload
impl From<GetVirtualChainFromBlockResponseMessage> for Payload
Sourcefn from(item: GetVirtualChainFromBlockResponseMessage) -> Self
fn from(item: GetVirtualChainFromBlockResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<&GetVirtualChainFromBlockResponse, RpcError>> for GetVirtualChainFromBlockResponseMessage
impl From<Result<&GetVirtualChainFromBlockResponse, RpcError>> for GetVirtualChainFromBlockResponseMessage
Sourcefn from(item: RpcResult<&GetVirtualChainFromBlockResponse>) -> Self
fn from(item: RpcResult<&GetVirtualChainFromBlockResponse>) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<GetVirtualChainFromBlockResponse, RpcError>> for GetVirtualChainFromBlockResponseMessage
impl From<Result<GetVirtualChainFromBlockResponse, RpcError>> for GetVirtualChainFromBlockResponseMessage
Sourcefn from(item: RpcResult<GetVirtualChainFromBlockResponse>) -> Self
fn from(item: RpcResult<GetVirtualChainFromBlockResponse>) -> Self
Converts to this type from the input type.
Sourceimpl Message for GetVirtualChainFromBlockResponseMessage
impl Message for GetVirtualChainFromBlockResponseMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetVirtualChainFromBlockResponseMessage
impl PartialEq for GetVirtualChainFromBlockResponseMessage
Sourcefn eq(&self, other: &GetVirtualChainFromBlockResponseMessage) -> bool
fn eq(&self, other: &GetVirtualChainFromBlockResponseMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetVirtualChainFromBlockResponseMessage