pub struct NotifyBlockAddedRequestMessage {
pub command: i32,
}Expand description
NotifyBlockAddedRequestMessage registers this connection for blockAdded notifications.
See: BlockAddedNotificationMessage
Fields
command: i32Implementations
Sourceimpl NotifyBlockAddedRequestMessage
impl NotifyBlockAddedRequestMessage
Sourcepub fn command(&self) -> RpcNotifyCommand
pub fn command(&self) -> RpcNotifyCommand
Returns the enum value of command, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command(&mut self, value: RpcNotifyCommand)
pub fn set_command(&mut self, value: RpcNotifyCommand)
Sets command to the provided enum value.