pub struct NotifyVirtualChainChangedResponseMessage {
pub error: Option<RpcError>,
}Fields
error: Option<RpcError>Trait Implementations
Sourceimpl Clone for NotifyVirtualChainChangedResponseMessage
impl Clone for NotifyVirtualChainChangedResponseMessage
Sourcefn clone(&self) -> NotifyVirtualChainChangedResponseMessage
fn clone(&self) -> NotifyVirtualChainChangedResponseMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<NotifyVirtualChainChangedResponseMessage> for KaspadResponse
impl From<NotifyVirtualChainChangedResponseMessage> for KaspadResponse
Sourcefn from(item: NotifyVirtualChainChangedResponseMessage) -> Self
fn from(item: NotifyVirtualChainChangedResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<NotifyVirtualChainChangedResponseMessage> for Payload
impl From<NotifyVirtualChainChangedResponseMessage> for Payload
Sourcefn from(item: NotifyVirtualChainChangedResponseMessage) -> Self
fn from(item: NotifyVirtualChainChangedResponseMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<&NotifyVirtualChainChangedResponse, RpcError>> for NotifyVirtualChainChangedResponseMessage
impl From<Result<&NotifyVirtualChainChangedResponse, RpcError>> for NotifyVirtualChainChangedResponseMessage
Sourcefn from(item: RpcResult<&NotifyVirtualChainChangedResponse>) -> Self
fn from(item: RpcResult<&NotifyVirtualChainChangedResponse>) -> Self
Converts to this type from the input type.
Sourceimpl From<Result<NotifyVirtualChainChangedResponse, RpcError>> for NotifyVirtualChainChangedResponseMessage
impl From<Result<NotifyVirtualChainChangedResponse, RpcError>> for NotifyVirtualChainChangedResponseMessage
Sourcefn from(item: RpcResult<NotifyVirtualChainChangedResponse>) -> Self
fn from(item: RpcResult<NotifyVirtualChainChangedResponse>) -> Self
Converts to this type from the input type.
Sourceimpl Message for NotifyVirtualChainChangedResponseMessage
impl Message for NotifyVirtualChainChangedResponseMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NotifyVirtualChainChangedResponseMessage
impl PartialEq for NotifyVirtualChainChangedResponseMessage
Sourcefn eq(&self, other: &NotifyVirtualChainChangedResponseMessage) -> bool
fn eq(&self, other: &NotifyVirtualChainChangedResponseMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<&NotifyVirtualChainChangedResponseMessage> for NotifyVirtualChainChangedResponse
impl TryFrom<&NotifyVirtualChainChangedResponseMessage> for NotifyVirtualChainChangedResponse
impl StructuralPartialEq for NotifyVirtualChainChangedResponseMessage