NotifyVirtualDaaScoreChangedRequestMessage

Struct NotifyVirtualDaaScoreChangedRequestMessage 

pub struct NotifyVirtualDaaScoreChangedRequestMessage {
    pub command: i32,
}
NotifyVirtualDaaScoreChangedRequestMessage registers this connection for virtualDaaScoreChanged notifications.

See: VirtualDaaScoreChangedNotificationMessage

Fields

command: i32

Implementations

Source

impl NotifyVirtualDaaScoreChangedRequestMessage

pub fn command(&self) -> RpcNotifyCommand

Returns the enum value of command, or the default if the field is set to an invalid enum value.

pub fn set_command(&mut self, value: RpcNotifyCommand)

Sets command to the provided enum value.