pub struct SubmitBlockRequestMessage {
pub block: Option<RpcBlock>,
pub allow_non_daa_blocks: bool,
}Expand description
SubmitBlockRequestMessage requests to submit a block into the DAG. Blocks are generally expected to have been generated using the getBlockTemplate call.
See: GetBlockTemplateRequestMessage
Fields
block: Option<RpcBlock>allow_non_daa_blocks: boolTrait Implementations
Sourceimpl Clone for SubmitBlockRequestMessage
impl Clone for SubmitBlockRequestMessage
Sourcefn clone(&self) -> SubmitBlockRequestMessage
fn clone(&self) -> SubmitBlockRequestMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubmitBlockRequestMessage
impl Debug for SubmitBlockRequestMessage
Sourceimpl Default for SubmitBlockRequestMessage
impl Default for SubmitBlockRequestMessage
Sourceimpl From<&SubmitBlockRequest> for SubmitBlockRequestMessage
impl From<&SubmitBlockRequest> for SubmitBlockRequestMessage
Sourcefn from(item: &SubmitBlockRequest) -> Self
fn from(item: &SubmitBlockRequest) -> Self
Converts to this type from the input type.
Sourceimpl From<SubmitBlockRequestMessage> for KaspadRequest
impl From<SubmitBlockRequestMessage> for KaspadRequest
Sourcefn from(item: SubmitBlockRequestMessage) -> Self
fn from(item: SubmitBlockRequestMessage) -> Self
Converts to this type from the input type.
Sourceimpl From<SubmitBlockRequestMessage> for Payload
impl From<SubmitBlockRequestMessage> for Payload
Sourcefn from(item: SubmitBlockRequestMessage) -> Self
fn from(item: SubmitBlockRequestMessage) -> Self
Converts to this type from the input type.
Sourceimpl Message for SubmitBlockRequestMessage
impl Message for SubmitBlockRequestMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for SubmitBlockRequestMessage