pub struct VirtualDaaScoreChangedNotificationMessage {
pub virtual_daa_score: u64,
}Expand description
VirtualDaaScoreChangedNotificationMessage is sent whenever the DAA score of the virtual changes.
See NotifyVirtualDaaScoreChangedRequestMessage
Fields
virtual_daa_score: u64Trait Implementations
Sourceimpl Clone for VirtualDaaScoreChangedNotificationMessage
impl Clone for VirtualDaaScoreChangedNotificationMessage
Sourcefn clone(&self) -> VirtualDaaScoreChangedNotificationMessage
fn clone(&self) -> VirtualDaaScoreChangedNotificationMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<&VirtualDaaScoreChangedNotification> for VirtualDaaScoreChangedNotificationMessage
impl From<&VirtualDaaScoreChangedNotification> for VirtualDaaScoreChangedNotificationMessage
Sourcefn from(item: &VirtualDaaScoreChangedNotification) -> Self
fn from(item: &VirtualDaaScoreChangedNotification) -> Self
Converts to this type from the input type.
Sourceimpl Message for VirtualDaaScoreChangedNotificationMessage
impl Message for VirtualDaaScoreChangedNotificationMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VirtualDaaScoreChangedNotificationMessage
impl PartialEq for VirtualDaaScoreChangedNotificationMessage
Sourcefn eq(&self, other: &VirtualDaaScoreChangedNotificationMessage) -> bool
fn eq(&self, other: &VirtualDaaScoreChangedNotificationMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<&VirtualDaaScoreChangedNotificationMessage> for VirtualDaaScoreChangedNotification
impl TryFrom<&VirtualDaaScoreChangedNotificationMessage> for VirtualDaaScoreChangedNotification
impl StructuralPartialEq for VirtualDaaScoreChangedNotificationMessage