pub struct NotifyVirtualDaaScoreChangedRequestMessage {
pub command: i32,
}Expand description
NotifyVirtualDaaScoreChangedRequestMessage registers this connection for virtualDaaScoreChanged notifications.
See: VirtualDaaScoreChangedNotificationMessage
Fields
command: i32Implementations
Sourceimpl NotifyVirtualDaaScoreChangedRequestMessage
impl NotifyVirtualDaaScoreChangedRequestMessage
Sourcepub fn command(&self) -> RpcNotifyCommand
pub fn command(&self) -> RpcNotifyCommand
Returns the enum value of command, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command(&mut self, value: RpcNotifyCommand)
pub fn set_command(&mut self, value: RpcNotifyCommand)
Sets command to the provided enum value.